@@ -8,7 +8,6 @@ from datetime import datetime
 import autonetkit.log as log
 import autonetkit.plugins.naming as naming
 import autonetkit.config
-settings = autonetkit.config.settings
 from autonetkit.ank_utils import alphabetical_sort as alpha_sort
 from autonetkit.ank import sn_preflen_to_network
 
@@ -111,7 +110,6 @@ class RouterCompiler(object):
         node.loopback_zero.id = self.lo_interface
         node.loopback_zero.description = "Loopback"
 
-
         for interface in node.physical_interfaces:
             phy_int = self.anm['phy'].interface(interface)
             interface.physical = True
@@ -400,6 +398,9 @@ class IosBaseCompiler(RouterCompiler):
         phy_node = self.anm['phy'].node(node)
 
         node.use_cdp = phy_node.use_cdp
+        if phy_node.device_subtype == "os":
+            # only copy across for certain reference platforms
+            node.use_onepk = phy_node.use_onepk
 
         if node in self.anm['ospf']:
             node.ospf.use_ipv4 = phy_node.use_ipv4
@@ -761,6 +762,7 @@ class NetkitCompiler(PlatformCompiler):
         self.lab_topology()
 
     def allocate_tap_ips(self):
+        settings = autonetkit.config.settings
         # TODO: take tap subnet parameter
         #TODO: this should be tuple of self.host and platform
         lab_topology = self.nidb.topology[self.host]
@@ -827,7 +829,6 @@ class NetkitCompiler(PlatformCompiler):
 
 class CiscoCompiler(PlatformCompiler):
     """Platform compiler for Cisco"""
-    to_memory = settings['Compiler']['Cisco']['to memory']
 
     # def __init__(self, nidb, anm, host):
 # TODO: setup to remap allocate interface id function here
@@ -878,6 +879,8 @@ class CiscoCompiler(PlatformCompiler):
             yield "GigabitEthernet0/0/0/%s" % x
 
     def compile(self):
+        settings = autonetkit.config.settings
+        to_memory = settings['Compiler']['Cisco']['to memory']
 #TODO: need to copy across the interface name from edge to the interface
         g_phy = self.anm['phy']
         use_mgmt_interfaces = g_phy.data.mgmt_interfaces_enabled 
@@ -915,7 +918,7 @@ class CiscoCompiler(PlatformCompiler):
             specified_int_names = phy_node.specified_int_names
             nidb_node = self.nidb.node(phy_node)
             nidb_node.render.template = os.path.join("templates","ios.mako")
-            if self.to_memory:
+            if to_memory:
                 nidb_node.render.to_memory = True
             else:
                 nidb_node.render.dst_folder = dst_folder
@@ -953,7 +956,7 @@ class CiscoCompiler(PlatformCompiler):
             specified_int_names = phy_node.specified_int_names
             nidb_node = self.nidb.node(phy_node)
             nidb_node.render.template = os.path.join("templates","ios2","router.conf.mako")
-            if self.to_memory:
+            if to_memory:
                 nidb_node.render.to_memory = True
             else:
                 nidb_node.render.dst_folder = dst_folder
@@ -980,7 +983,7 @@ class CiscoCompiler(PlatformCompiler):
         for phy_node in g_phy.nodes('is_router', host=self.host, syntax='nx_os'):
             nidb_node = self.nidb.node(phy_node)
             nidb_node.render.template = os.path.join("templates","nx_os.mako")
-            if self.to_memory:
+            if to_memory:
                 nidb_node.render.to_memory = True
             else:
                 nidb_node.render.dst_folder = dst_folder
@@ -1048,14 +1051,17 @@ class CiscoCompiler(PlatformCompiler):
 
         mgmt_subnet = start_subnet
         hosts_to_allocate = sorted(self.nidb.nodes('is_router', host=self.host))
+        dhcp_subtypes = {"os"}
+        dhcp_hosts = [h for h in hosts_to_allocate if h.device_subtype in dhcp_subtypes]
+        non_dhcp_hosts = [h for h in hosts_to_allocate if h.device_subtype not in dhcp_subtypes]
 
         try: # validation
-            assert(len(mgmt_ips) >= len(hosts_to_allocate))
+            assert(len(mgmt_ips) >= len(non_dhcp_hosts))
             log.debug("Verified: Cisco management IP range is sufficient size %s for %s hosts"
-                    % (len(mgmt_ips), len(hosts_to_allocate)))
+                    % (len(mgmt_ips), len(non_dhcp_hosts)))
         except AssertionError:
             log.warning("Error: Cisco management IP range is insufficient size %s for %s hosts"
-                    % (len(mgmt_ips), len(hosts_to_allocate)))
+                    % (len(mgmt_ips), len(non_dhcp_hosts)))
             # TODO: need to use default range
             return
 
@@ -1063,12 +1069,16 @@ class CiscoCompiler(PlatformCompiler):
             for interface in nidb_node.physical_interfaces:
                 if interface.management:
                     interface.description = "OOB Management"
-                    ipv4_address = mgmt_ips_iter.next()
-                    interface.ipv4_address = ipv4_address
-                    interface.ipv4_subnet = mgmt_subnet
-                    interface.ipv4_cidr = sn_preflen_to_network(ipv4_address, mgmt_prefixlen)
                     interface.physical = True
-                    oob_management_ips[str(nidb_node)] = ipv4_address
+                    if nidb_node in dhcp_hosts:
+                        interface.use_dhcp = True
+                        oob_management_ips[str(nidb_node)] = "dhcp"
+                    else:
+                        ipv4_address = mgmt_ips_iter.next()
+                        interface.ipv4_address = ipv4_address
+                        interface.ipv4_subnet = mgmt_subnet
+                        interface.ipv4_cidr = sn_preflen_to_network(ipv4_address, mgmt_prefixlen)
+                        oob_management_ips[str(nidb_node)] = ipv4_address
 
         lab_topology.oob_management_ips = oob_management_ips
 
