@@ -66,6 +66,7 @@ def render_node(node, folder_cache):
         log.debug("Rendering %s" % node)
         try:
             render_output_dir = node.render.dst_folder
+            #TODO: could check if base is set, so don't put error into debug log
             render_base = node.render.base
             render_base_output_dir = node.render.base_dst_folder
             render_template_file = node.render.template
@@ -122,7 +123,7 @@ def render_node(node, folder_cache):
 
             if node.render.to_memory:
 # Render directly to NIDB
-                node.render.to_memory = render_template.render(
+                node.render.render_output = render_template.render(
                             node = node,
                             ank_version = ank_version,
                             date = date,
@@ -308,6 +309,11 @@ def render_topology(topology):
     except KeyError, error:
         return
 
+    if not render_template_file:
+        log.debug("No render template specified for topology %s, skipping" 
+                % topology)
+        return
+
     try:
         render_template = lookup.get_template(render_template_file)
     except SyntaxException, error:
