@@ -1632,6 +1632,10 @@ function redraw() {
         .style("opacity",0)
         .remove();
     //});
+    
+
+        pathinfo = [];
+        redraw_paths();
         }
 
 function redraw_paths() {
@@ -1666,7 +1670,7 @@ function redraw_paths() {
 
     var path_color = function(d) { 
         if ("verified" in d && d['verified'] == true) {
-            return "red";
+            return "green";
         }
         return "red";
     }
